# Hinweise für den Versuch Schaltlogik

## Gatter

Logische Verknüpfungen (Gatter) werden z.B. durch **[Wahrheitstabellen](https://de.wikipedia.org/wiki/Wahrheitstabelle)** definiert. Grundlegende Gatter sind z.B. 

- AND,
- OR,
- XOR,
- NOT.

Die nach [IEC-Norm gebräuchlichen Schaltsymbole](https://de.wikipedia.org/wiki/Logikgatter#Typen_von_Logikgattern_und_Symbolik) der in diesem Versuch verwendeten Gatter sind in **Abbildung 1** gezeigt:

---

<img src="../figures/Symbole-Gatter.png" width="1000" style="zoom:100%;" />

**Abbildung 1**: (Schaltsymbole der in diesem Versuch verwendeten Gatter, nach IEC-Norm)

---

Zur Beschreibung binärer Verknüpfungen (wie dem AND oder dem OR) definieren wir **A und B als Eingänge und Y als den Ausgang des Gatters**. Außerdem führen wir die folgenden Bezeichnungen ein: 

- **0/LOW**: GND ($0\ \mathrm{V}$)
- **1/HIGH**: VCC ($+5\ \mathrm{V}/+3.3\ \mathrm{V}$).

Die Zustände 0 und 1 werden durch die elektrischen Potentiale an A, B und Y identifiziert. 

- Beim in **Aufgabe 1** verwendeten Schaltbrett (CMOS $5\ \mathrm{V}$-Standard) handelt es sich dabei um 0 und $+5\ \mathrm{V}$. 
- Bei der ab **Aufgabe 2** verwendeten [MAXwel-Platine](https://github.com/MitchiLaser/MAXwel/tree/master) zur Ansteuerung eines FPGA (LVTTL $3.3\ \mathrm{V}$-Standard) handelt es sich um 0 und $+3.3\ \mathrm{V}$. 

Während es sich bei 0 und 1 um wohldefinierte logische Zustände handelt liegen die analogen Potentiale immer mit einer gewissen Varianz vor. Zudem kann es, je nach Art der Schaltung zu Verzerrungen der Potentiale kommen (siehe Diskussion zu Dioden- und Transistoren-Gattern weiter unten im Text). 

Dementsprechend wird der Spannungs-Bereich, bei dem sich ein Logikgatter so verhält, als würde der Zustand 1 anliegen, als [HIGH-Pegel](https://de.wikipedia.org/wiki/Logikpegel)  bezeichnet. Alle Eingangsspannungen, bei denen sich das Logikgatter so verhält, als würde der Zustand 0 anliegen werden als [LOW-Pegel](https://de.wikipedia.org/wiki/Logikpegel) bezeichnet.

## OR-Gatter

Die Wahrheitstafel für das **OR-Gatter** ist
$$
\begin{equation*}
\begin{array}{cc|c}
    \mathrm{A} &   \mathrm{B} &   \mathrm{Y = A \lor B} \\
    \hline
    0 &   0 &   0 \\
    0 &   1 &   1 \\
    1 &   0 &   1 \\
    1 &   1 &   1 \\
\end{array}
\end{equation*}
$$
Das Schaltsymbol für das OR-Gatter ist in **Abbildung 1a** gezeigt. Die einfachste Realisierung erfolgt mit Hilfe von zwei Dioden, wie in **Abbildung 2** gezeigt:

---

<img src="../figures/Dioden-OR.png" width="1000" style="zoom:100%;" />

**Abbildung 2**: (Realisierung eines OR-Gatters mit Hilfe von zwei Dioden)

---

- Liegt **entweder A oder B auf HIGH** ($+5\ \mathrm{V}$), ﬂießt Strom durch den Widerstand $R$ und die Diode $D_{\mathrm{A}}$ oder die Diode $D_{\mathrm{B}}$ wird in **Durchlassrichtung** betrieben. In Durchlassrichtung fällt an einer Silizium-Diode die Knickspannung ([Schwellenspannung](https://de.wikipedia.org/wiki/Schwellenspannung))

  ```math
  \begin{equation*}
  U_{D}\approx-0.7\,\mathrm{V}
  \end{equation*}
  ```

  ab (siehe [Hinweise zum Versuch Transistor und Operationsverstärker](https://gitlab.kit.edu/kit/etp-lehre/p1-praktikum/students/-/blob/main/Transistor_und_Operationsverstaerker/doc/Hinweise-Transistor.md)), der Großteil der Spannung fällt also über $R$ ab und Y liegt auf hohem Potential, d.h. auf HIGH.

- Liegen jedoch **weder A noch B auf HIGH**, so ﬂießt kein Strom. Da kein Strom fließt fällt auch keine Spannung über $R$ ab und Y liegt auf LOW ($0\ \mathrm{V}$). 

- Falls ein Eingang auf HIGH und der andere auf LOW liegt, ist immer eine der beiden Dioden in **Sperrichtung** geschaltet, so dass kein Strom zwischen A und B fließt.

## AND-Gatter

 Die Wahrheitstafel für das **AND-Gatter** ist
$$
\begin{equation*}
\begin{array}{cc|c}
    \mathrm{A} &   \mathrm{B} &   \mathrm{Y = A \land B} \\
    \hline
    0 &   0 &   0 \\
    0 &   1 &   0 \\
    1 &   0 &   0 \\
    1 &   1 &   1 \\
\end{array}
\end{equation*}
$$
Das Schaltsymbol für das AND-Gatter ist in **Abbildung 1b** gezeigt.

### Dioden-AND-Gatter

Die einfachste Realisierung eines AND-Gatters erfolgt mit Hilfe von zwei Dioden, wie in **Abbildung 3** gezeigt:

---

<img src="../figures/Dioden-AND.png" width="1000" style="zoom:100%;" />

**Abbildung 3**: (Realisierung eines AND-Gatters mit Hilfe von zwei Dioden)

---

- Liegt **entweder A oder B auf LOW**, ﬂießt Strom durch $R$ und die Diode $D_{\mathrm{A}}$ oder $D_{\mathrm{B}}$ wird in **Durchlassrichtung** betrieben, der Großteil der Spannung fällt also über $R$ ab und Y liegt auf niedrigem Potential, d.h. auf LOW.
- Liegen jedoch **sowohl A als auch B auf HIGH**, so ﬂießt kein Strom. Alle Eingangspunkte der Schaltung liegen auf dem gleichen Potential von $+5\ \mathrm{V}$. Da kein Strom fließt fällt auch keine Spannung ab und Y liegt auf HIGH. 
- Falls ein Eingang auf HIGH und der andere auf LOW liegt, ist immer eine der beiden Dioden in **Sperrichtung** geschaltet, so dass kein Strom zwischen A und B fließt.

Durch $U_{D}$ ist das Potential für LOW an Y etwas höher als an den Eingängen von $D_{\mathrm{A}}$ und $D_{\mathrm{B}}$. Dadurch ist die Anzahl an Dioden-Gattern, die man hintereinander schalten kann begrenzt. Dieser Nachteil lässt sich durch die Verwendung von Transistoren umgehen.

### Transistor-AND-Gatter

Die Realisierung eines AND-Gatters mit Hilfe von zwei Transistoren ist in **Abbildung 4** gezeigt:

---

<img src="../figures/Transistor-AND.png" width="400" style="zoom:100%;" />

**Abbildung 4**: (Realisierung eines AND-Gatters mit Hilfe von zwei Transistoren)

---

- Transistoren kennen Sie aus dem Versuch [Transistor und Operatonsverstärker](https://gitlab.kit.edu/kit/etp-lehre/p1-praktikum/students/-/tree/main/Transistor_und_Operationsverstaerker). Hier wird der Transistor nicht als Verstärker, sondern als Schalter verwendet: Liegt an der Basis keine Spannung an ($U_{\mathrm{B}}=0$) befindet sich der Transistor im **Sperrbetrieb**, für den Widerstand zwischen Kollektor und Emitter gilt $r_{\mathrm{C}}\gg 0$ und es fließt kein Strom. Da es zu keinem Stromfluss kommt liegt Y auf dem gleichen Potential wie GND und damit auf LOW. 
- Für $U_{\mathrm{B}}+U_{D}>0$ gilt $r_{\mathrm{C}}\approx 0$ und der Transistor befindet sich im **Sättigungsbetrieb**. Durch die Reihenschaltung von zwei Transistoren kommt es zum Stromfluss über $R_{E}$ nur dann, wenn **sowohl A als auch B auf HIGH** liegen. Durch $r_{\mathrm{C}}\approx0$ fällt in diesem Fall die gesamte Spannung über $R_{E}$ ab und Y liegt auf HIGH. 

Die Vorwiderstände $R_{V}$ dienen zur Stabilisierung des Transistors (siehe Diskussion des Transistors für den Versuch [Transistor und Operationsverstärker](https://gitlab.kit.edu/kit/etp-lehre/p1-praktikum/students/-/blob/main/Transistor_und_Operationsverstaerker/doc/Hinweise-Emitterschaltung.md)).

## NOT-Gatter

Die Wahrheitstafel für das **NOT-Gatter** ist
$$
\begin{equation*}
\begin{array}{c|c}
    \mathrm{A} & \mathrm{Y = \overline{A}} \\
    \hline
    0 &  1 \\
    1 &  0 \\
\end{array}
\end{equation*}
$$
Das entsprechende Schaltsymbol ist in **Abbildung 1c** gezeigt. Am einfachsten lässt sich das NOT-Gatter mit Hilfe eines Transistors realisieren, wie in **Abbildung 5** gezeigt:

---

<img src="../figures/Transistor-NOT.png" width="500" style="zoom:100%;" />

**Abbildung 5**: (Realisierung eines NOT-Gatters mit Hilfe eines Transistors)

---

- Liegt A auf HIGH befindet sich der Transistor im **Sättigungsbetrieb**, es gilt $r_{\mathrm{C}}\approx0$ und Y liegt auf LOW. 
- Liegt A auf LOW befindet sich der Transistor im **Sperrbetrieb**, es gilt $r_{\mathrm{C}}\gg0$, es fließt kein Strom und Y liegt auf HIGH.

## NAND-Gatter

Kombiniert man ein AND- mit einem NOT-Gatter erhält man ein **NAND-Gatter**. Die entsprechende Wahrheitstafel für das NAND-Gatter ist
$$
\begin{equation*}
\begin{array}{cc|c}
    \mathrm{A} &   \mathrm{B} &   \mathrm{Y = \overline{A \land B}} \\
    \hline
    0 &   0 &   1 \\
    0 &   1 &   1 \\
    1 &   0 &   1 \\
    1 &   1 &   0 \\
\end{array}
\end{equation*}
$$
Das Schaltsymbol ist in **Abbildung 1d** gezeigt. Die Realisierung erfolgt, z.B. wie in **Abbildung 6** gezeigt:

---

<img src="../figures/NAND-mit-Transistor.png" width="600" style="zoom:100%;" />

**Abbildung 6**: (Realisierung eines NAND-Gatters mit Hilfe von zwei Dioden und einem Transistor)

---

## Realisierung auf dem Schaltbrett

Die Realisierung aller relevanten Schaltungen aus **Aufgabe 1** erfolgt, bis auf die Kippschalter und Leuchtdioden, im Bereich (3) des Schaltbretts aus **Abbildung 1** [hier](https://gitlab.kit.edu/kit/etp-lehre/p1-praktikum/students/-/blob/main/Schaltlogik/doc/Hinweise-Schaltbrett.md). Eine Vergrößerung dieses Bereichs ist in **Abbildung 7** gezeigt:

---

<img src="../figures/Schaltbrett-Aufgabe-1.png" width="1000" style="zoom:100%;" />

**Abbildung 7**: (Vergrößerung des Bereichs (3) zur Realisierung der Dioden-Gatter)

---

Unten links in der Vergrößerung sind zwei Dioden $D_{\mathrm{A}}$ und $D_{\mathrm{B}}$ zu sehen, die Sie für die **Schaltung der Dioden-OR und AND Gatter** verwenden können. Schwarze Striche auf den Glaskolben der Dioden (die dem Balken des Schaltsymbols entsprechen) zeigen die Durchlassrichtung der Dioden an. 

Durch die schwarz isolierten Kabel ist der Transistor (rechts in der Vergrößerung) bereits für das NOT-Gatter aus **Abbildung 5** vorverschaltet: 

- Das untere Kabel verbindet den Emitter mit GND. 
- Das mittlere Kabel verbindet den Kollektor über $R_{C}$ mit VCC. 
- Zwischen $R_{V}$ und dem Transistor kann der **Ausgang Y des Gatters** abgegriffen werden. 
- Das obere Kabel verbindet die Basis des Transistors mit einer Linie aus einer Diode $D_{V}$ und einem Widerstand $R_{V}$. Hinter $R_{V}$ liegt der **Eingang A des Gatters**. 
- Die zusätzliche Diode $D_{V}$ auf dem Schaltbrett ist für die Schaltung eigentlich irrelevant und in **Abbildung 5** nicht enthalten. 

# Navigation

[Main](https://gitlab.kit.edu/kit/etp-lehre/p1-praktikum/students/-/tree/main/Schaltlogik)

