# Hinweise für den Versuch Schaltlogik

## Schaltung eines NOT- aus einem NOR-Gatter

Die Wahrheitstafel für das **NOR-Gatter** ist
$$
\begin{equation}
\begin{array}{cc|c}
    \mathrm{A} &   \mathrm{B} &   \mathrm{Y = \overline{A \lor B}} \\
    \hline
    \mathbf{0} &   \mathbf{0} &   \mathbf{1} \\
    0 &   1 &   0 \\
    1 &   0 &   0 \\
    \mathbf{1} &   \mathbf{1} &   \mathbf{0} \\
\end{array}
\end{equation}
$$
Dieses lässt sich zu einem **NOT-Gatter für den Eingang A** reduzieren, indem man die Bedingung 
$$
\begin{equation*}
\mathrm{A=B}
\end{equation*}
$$
an den Eingängen A und B implementiert, wie aus den hervorgehobenen **Zeilen 1 und 4 der Wahrheitstafel in Gleichung (1)** zu erkennen ist. 

Man erhält das gleiche Ergebnis, für die Bedingung
$$
\begin{equation}
\begin{split}
&\begin{array}{cc|c}
    \mathrm{A} &   \mathrm{B} &   \mathrm{Y = \overline{A \lor B}} \\
    \hline
    \mathbf{0} &   \mathbf{0} &   \mathbf{1} \\
    0 &   1 &   0 \\
    \mathbf{1} &   \mathbf{0} &   \mathbf{0} \\
    1 &   1 &   0 \\
\end{array} \\
&\\
&\text{mit: } \mathrm{B=0},\\
\end{split}
\end{equation}
$$
wie in den hervorgehobenen **Zeilen 1 und 3 in der Wahrheitstafel aus Gleichung (2)** zu sehen ist.

## Schaltung eines NOT- aus einem NAND-Gatter

Ähnliche Bedingungen kann man ableiten, um das NAND- zu einem NOT-Gatter zu reduzieren, wie in Gleichungen **(3)** gezeigt:
$$
\begin{equation}
\begin{split}
&\begin{array}{cc|c}
    \mathrm{A} &   \mathrm{B} &   \mathrm{Y = \overline{A \land B}} \\
    \hline
    \mathbf{0} &   \mathbf{0} &   \mathbf{1} \\
    0 &   1 &   1 \\
    1 &   0 &   1 \\
    \mathbf{1} &   \mathbf{1} &   \mathbf{0} \\
\end{array}\\
&\\
&\text{mit: } \mathrm{A=B}\\
&\\
&\\
&\begin{array}{cc|c}
    \mathrm{A} &   \mathrm{B} &   \mathrm{Y = \overline{A \land B}} \\
    \hline
    0 &   0 &   1 \\
    \mathbf{0} &   \mathbf{1} &   \mathbf{1} \\
    1 &   0 &   1 \\
    \mathbf{1} &   \mathbf{1} &   \mathbf{0} \\
\end{array}\\
&\\
&\text{mit: } \mathrm{B=1}.\\
\end{split}
\end{equation}
$$

## XOR-Gatter

Die Wahrheitstafel für das **XOR-Gatter** ist
$$
\begin{equation}
\begin{array}{cc|c}
    \mathrm{A} &   \mathrm{B} &   \mathrm{Y = A \underline{\lor} B} \\
    \hline
    0 &   0 &   0 \\
    0 &   1 &   1 \\
    1 &   0 &   1 \\
    1 &   1 &   0 \\
\end{array}
\end{equation}
$$
Der Begriff XOR steht für die Aussage **"entweder oder"**, auch als "exklusives oder" oder "*exclusive or*" bezeichnet. Das Schaltsymbol für das XOR-Gatter ist in **Abbildung 1e** [hier](https://gitlab.kit.edu/kit/etp-lehre/p1-praktikum/students/-/blob/main/Schaltlogik/doc/Hinweise-Gatter.md) gezeigt. 

Jede logische Funktion lässt sich in der [**disjunktiven Normalform**](https://de.wikipedia.org/wiki/Disjunktive_Normalform) als [Disjunktion](https://de.wikipedia.org/wiki/Disjunktion) von [Konjunktionen](https://de.wikipedia.org/wiki/Konjunktionsterm), d.h. als OR-Verknüpfung von AND-Verknüpfungen darstellen.  Diese lässt sich zeilenweise aus Gleichung **(4)** zu 
$$
\begin{equation}
\mathrm{Y} = \left(\mathrm{\overline{A}\,\land\,B}\right)\lor\left(\mathrm{A\,\land\,\overline{B}}\right)
\end{equation}
$$
ablesen. Ein mögliche Realierung dieser Schaltung mit Hilfe von zwei  NOT-, zwei AND- und einem OR-Gatter ist in **Abbildung 1** gezeigt:

---

<img src="../figures/Schaltung-XOR.png" width="1000" style="zoom:100%;" />

**Abbildung 1**: (Realisierung eines XOR-Gatters mit Hilfe von zwei NOT-, zwei AND- und einem OR-Gatter)

---

- A läuft in das obere NOT- und von dort mit B in das untere AND-Gatter.
- B läuft in das untere NOT- und von dort mit A in das obere AND-Gatter.
- Die Ausgänge beider AND-Gatter stellen die Eingänge in das abschließende OR-Gatter dar. 

**Auf diese Weise lässt sich jede logische Funktion realisieren.** 

Eine alternative Darstellung bestehend nur aus NAND-Gattern lässt sich wie folgt ableiten:

Man erweitert Gleichung **(5)** zunächst zweimal mit der Aussage "$\lor\,0$"
$$
\begin{equation*}
\begin{split}
\mathrm{Y} &= \left(\mathrm{\overline{A}\,\land\,B}\right)\lor\left(\mathrm{A\,\land\,\overline{B}}\right) \\
&\\
&=\left(\mathrm{\overline{A}\,\land\,B}\right)\lor\underbrace{\left(\mathrm{\overline{B}\,\land\,B}\right)}\lor
\left(\mathrm{A\,\land\,\overline{B}}\right)\lor\underbrace{\left(\mathrm{A\,\land\,\overline{A}}\right)},\\
&\hphantom{ccccccccccccccccc}\equiv 0
\hphantom{cccccccccccccccccccc}\equiv 0\\
\end{split}
\end{equation*}
$$
wobei es sich bei 
$$
\begin{equation*}
0\equiv\mathrm{\overline{B}\,\land\,B} = \mathrm{\overline{A}\,\land\,A}
\end{equation*}
$$
jeweils um das **unmögliche Ereignis** handelt, weil nicht A (B) und gleichzeitig "nicht-A (B)" wahr sein kann. 

Im nächsten Schritt lassen sich nach dem Assoziativ-Gesetz B aus den linken und A aus den rechten beiden Klammern des entstehenden Ausdrucks ausklammern: 
$$
\begin{equation*}
\begin{split}
\mathrm{Y} &=\left(\mathrm{\overline{A}\,\land\,B}\right)\lor\left(\mathrm{\overline{B}\,\land\,B}\right)\lor
\left(\mathrm{A\,\land\,\overline{B}}\right)\lor\left(\mathrm{A\,\land\,\overline{A}}\right)\\
&\\
&=\mathrm{\left(\left(\overline{A}\,\lor\,\overline{B}\right)\land\,B\right)\lor
\left(A\,\land\left(\overline{B}\,\lor\,\overline{A}\right)\right).}
\end{split}
\end{equation*}
$$
Im nächsten Schritt werden beide inneren Klammerterme zweimal negiert, was einer weiteren Äquivalenzumformung entspricht und die:
$$
\begin{equation}
\begin{split}
\mathrm{Y} &=\mathrm{\left(\overline{\overline{\left(\overline{A}\,\lor\,\overline{B}\right)}}\land\,B\right)\lor
\left(A\,\land\overline{\overline{\left(\overline{B}\,\lor\,\overline{A}\right)}}\right)}\\
&\\
&=\mathrm{\left(\overline{\left(A\,\land\,B\right)}\land\,B\right)\lor
\left(A\,\land\overline{\left(B\,\land\,A\right)}\right)};\\
&\\
&\text{mit:} \\
&\\
&\mathrm{\overline{A\,\lor\,B} = \overline{A}\,\land\,\overline{B}}.\\
\end{split}
\end{equation}
$$
Beim letzten Term in Gleichung **(6)** handelt es sich um eines der [**De-Morganschen Gesetze**](https://de.wikipedia.org/wiki/De-morgansche_Gesetze). 

Nochmalige zweifache Negation des Ausdrucks aus Gleichung **(6)** sowie die erneute Anwendung der De-Morganschen Regeln führt auf:
$$
\begin{equation}
\begin{split}
\mathrm{Y} &=\mathrm{
\overline{\overline{
\left(
\overline{\left(A\,\land\,B\right)}
\land\,B\right)
\,\lor\,
\left(A\,\land
\overline{\left(B\,\land\,A\right)}
\right)}};}\\
&\\
&=\mathrm{
\overline{
\overline{
\left(
\overline{\left(A\,\land\,B\right)}\land\,B\right)}
\,\land\,
\overline{
\left(
A\,\land
\overline{\left(B\,\land\,A\right)}
\right)}}}.\\
\end{split}
\end{equation}
$$
Der letzte Ausdruck in Gleichung **(7)** besteht aus einer dreifachen Schachtelung von NAND-Gattern. Eine entsprechende Schaltung ist in **Abbildung 2** gezeigt:

---

<img src="../figures/Schaltung-XOR-from-NAND.png" width="1000" style="zoom:100%;" />

**Abbildung 2**: (Realisierung eines XOR-Gatters mit Hilfe nur von NAND-Gattern)

---

- A und B laufen in das erste NAND-Gatter von links.
- A und $\mathrm{\overline{\left(B\,\land\,A\right)}}$ laufen in das obere NAND-Gatter.
- $\mathrm{\overline{\left(B\,\land\,A\right)}}$ und B laufen in das untere NAND-Gatter.
- Die Ausgänge beider mittleren Gatter stellen die Eingänge des rechten NAND-Gatters dar. 

Der Vorteil solcher Umformungen liegt darin, dass danach nur noch ein Typ von Gattern benötigt wird. Dies ist besonders für große Schaltungen von Bedeutung, da sich dadurch der Herstellungsaufwand sowie dessen Kosten stark senken lassen. 

# Navigation

[Main](https://gitlab.kit.edu/kit/etp-lehre/p1-praktikum/students/-/tree/main/Schaltlogik)

